==> springfox-core-2.2.0-sources.jar: springfox/documentation/service/ResponseMessage.java <==
/*
 *
 *  Copyright 2015 the original author or authors.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *
 */

package springfox.documentation.service;

import springfox.documentation.schema.ModelRef;

public class ResponseMessage {
  private final int code;
  private final String message;
  private final ModelRef responseModel;

  public ResponseMessage(int code, String message, ModelRef responseModel) {
    this.code = code;
    this.message = message;
    this.responseModel = responseModel;
  }

  public int getCode() {
    return code;
  }

  public String getMessage() {
    return message;
  }

  public ModelRef getResponseModel() {
    return responseModel;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }

    ResponseMessage that = (ResponseMessage) o;

    return code == that.code;

  }

  @Override
  public int hashCode() {
    return code;
  }
}

==> springfox-core-2.3.1-sources.jar: springfox/documentation/service/ResponseMessage.java <==
/*
 *
 *  Copyright 2015 the original author or authors.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *
 */

package springfox.documentation.service;

import springfox.documentation.schema.ModelReference;

public class ResponseMessage {
  private final int code;
  private final String message;
  private final ModelReference responseModel;

  public ResponseMessage(int code, String message, ModelReference responseModel) {
    this.code = code;
    this.message = message;
    this.responseModel = responseModel;
  }

  public int getCode() {
    return code;
  }

  public String getMessage() {
    return message;
  }

  public ModelReference getResponseModel() {
    return responseModel;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }

    ResponseMessage that = (ResponseMessage) o;

    return code == that.code;

  }

  @Override
  public int hashCode() {
    return code;
  }
}
